<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="50%"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-position="top" label-width="150px" >
        <el-form-item label="企业名称:" prop="companyId" v-if="state.isAdmin">
          <el-select
              v-model="state.form.companyId"
              filterable
              clearable
              style="width: 100%"
              :disabled="title == '查看' || title == '编辑' || !state.isAdmin"
              @change="selectValueCom"
          >
            <el-option
                v-for="item in state.companyList"
                :key="item.id"
                :label="item.name"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="年份:" prop="year" >
          <el-select
              :disabled="title === '查看'"
              v-model="state.form.year"
              filterable
              allow-create
              default-first-option
              :reserve-keyword="false"
              @change="handleChangeNum"
              style="width: 100%"
          >
            <el-option
                v-for="item in state.yearList"
                :key="item.value"
                :label="item.label"
                :value="item.label"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="1.目的" prop="purpose" >
          <el-input v-model="state.form.purpose" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="2.内审目的" prop="auditPurpose" >
          <el-input v-model="state.form.auditPurpose" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="3.审核范围" prop="reviewScope" >
          <el-input v-model="state.form.reviewScope" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="4.审核依据" prop="reviewBasis" >
          <el-input v-model="state.form.reviewBasis" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="5.审核实施" prop="reviewCarry" >
          <el-input v-model="state.form.reviewCarry" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="6.审核组构成" prop="reviewConstitute" >
          <el-input v-model="state.form.reviewConstitute" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
        <el-form-item label="7.要求" prop="reviewRequire" >
          <el-input v-model="state.form.reviewRequire" :rows="4" type="textarea" :disabled="title === '查看'"/>
        </el-form-item>
      </el-form>
      <el-form :model="state.form" size="default" ref="peoRef" :rules="state.peoRules"  label-width="60px">
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="编制:" prop="compilationId" >
              <el-select clearable v-model="state.form.compilationId" :disabled="title =='查看'" filterable  style="width: 240px">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="校对:" prop="proofreadId" >
              <el-select clearable v-model="state.form.proofreadId" :disabled="title =='查看'" filterable  style="width: 240px">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="审核:" prop="checkId" >
              <el-select clearable v-model="state.form.checkId" :disabled="title =='查看'" filterable  style="width: 240px">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="批准:" prop="ratifyId" >
              <el-select clearable v-model="state.form.ratifyId" :disabled="title =='查看'" filterable  style="width: 240px">
                <el-option
                    v-for="item in state.peopleList"
                    :key="item.id"
                    :label="item.name"
                    :value="item.id"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer v-if="title !== '查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"   @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {onMounted, reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail} from "@/api/backManage/evaluate";
import {addCompany, checkName, distributeCompany, editCompany, getCompany} from "@/api/onlineEducation/company";
import {verifyPhone} from "@/utils/validate";
import {addBasic, editBasic} from "@/api/companyInfo/basicInfo";
import Cookies from "js-cookie";
import {getUser} from "@/api/onlineEducation/user";
import {addScenario, editScenario} from "@/api/selfProblems/scenario";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const peoRef = ref()
const length = ref()
const emit = defineEmits(["getList"]);
const state = reactive({
  form: {
    id: '',
    companyId: null,
    year: "",
    purpose: "",
    auditPurpose: "",
    reviewBasis: "",
    reviewScope: "",
    reviewCarry: "",
    reviewConstitute: "",
    reviewRequire: "",
    compilationId: null,
    proofreadId: null,
    checkId: null,
    ratifyId: null
  },
  formRules:{
    companyId: [{ required: true, message: '请选择企业', trigger: 'blur' }],
    year: [{ required: true, message: '请选择年份', trigger: 'blur' }],
    purpose:[{ required: true, message: '请输入目的', trigger: 'blur' }],
    auditPurpose: [{ required: true, message: '请输入审核目的', trigger: 'blur' }],
    reviewBasis: [{ required: true, message: '请输入审核依据', trigger: 'blur' }],
    reviewScope: [{ required: true, message: '请输入审核范围', trigger: 'blur' }],
    reviewCarry: [{ required: true, message: '请输入审核实施', trigger: 'blur' }],
    reviewConstitute: [{ required: true, message: '请输入审核组构成', trigger: 'blur' }],
    reviewRequire: [{ required: true, message: '请输入要求', trigger: 'blur' }],

  },
  peoRules: {
    compilationId: [{ required: true, message: '请选择编制人', trigger: 'blur' }],
    proofreadId: [{ required: true, message: '请选择校对人', trigger: 'blur' }],
    checkId: [{ required: true, message: '请选择审核人', trigger: 'blur' }],
    ratifyId: [{ required: true, message: '请选择批准人', trigger: 'blur' }],
  },
  isAdmin: false,
  companyList: [],
  yearList: [
    {
      value: 1,
      label: '2025'
    },
    {
      value: 2,
      label: '2024'
    },
    {
      value: 3,
      label: '2023'
    },
    {
      value: 4,
      label: '2022'
    },
    {
      value: 5,
      label: '2021'
    },
  ],
  peopleList: [],
})

onMounted(() => {

})
const openDialog = async (type, value,companyList) => {

  const userInfo = JSON.parse(Cookies.get('userInfo'))
  state.isAdmin = userInfo.userType === 0;
  state.form.companyName = userInfo.companyName
  state.form.companyId = userInfo.companyId
  if(state.isAdmin){
   state.companyList = companyList
    state.form.companyId = value.companyId
    state.form.companyName = value.companyName
  }
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
  if(type === 'edit' || type === 'review') {
    state.form = JSON.parse(JSON.stringify(value));
    if(state.isAdmin){
      state.form.companyId = value.companyId
      state.form.companyName = value.companyName
    }
  }
  await   getPeopleList()
  dialogVisible.value = true;
}
const getPeopleList = async ()=> {
  if(state.isAdmin && !state.form.companyId && (state.form.companyId == 0 || state.form.companyId == null)){
    return
  }
  const queryParams = {
    pageNum: 1,
    pageSize: 9999,
    companyId: state.form.companyId
  }
  const res = await getUser(queryParams)
  if(res.code == 200){
    state.peopleList = res.data.list?res.data.list:[]
  }else{
    ElMessage.warning(res.message)
  }
};

const onSubmit = async () => {
  const valid = await busRef.value.validate();
  const validPro = await peoRef.value.validate();
  if(!state.isAdmin){
    const userInfo = JSON.parse(Cookies.get('userInfo'))
    state.form.companyId = userInfo.companyId
  }
  if(valid && validPro){
    if(title.value === '新增'){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addScenario(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      peoRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editScenario(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      peoRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  peoRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const handleChangeNum = (value) => {
  if (!/^\d+$/.test(value)) { // 验证是否为数字
    ElMessage.warning('只能输入数字')
    state.form.year = '' // 重置选择，避免非法值被添加到options中
  } else if (!state.yearList.some(option => option.label === value)) { // 确保不是已存在的选项
    state.yearList.push({ value, label: value }); // 添加新选项（这里简单地将值和标签设为相同）
  }
}
const selectValueCom = (val) => {
  state.form.compilationId = null
  state.form.proofreadId = null
  state.form.checkId = null
  state.form.ratifyId = null
  getPeopleList()
}
const reset = () => {
  state.form = {
    id: '',
    companyId: null,
    year: "",
    purpose: "",
    auditPurpose: "",
    reviewBasis: "",
    reviewScope: "",
    reviewCarry: "",
    reviewConstitute: "",
    reviewRequire: "",
    compilationId: null,
    proofreadId: null,
    checkId: null,
    ratifyId: null
  }
  state.companyList = []
  state.peopleList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
